@@ -8,7 +8,7 @@
  *	New quota format implementation - Jan Kara <jack@suse.cz> - Sponsored by SuSE CR
  */
 
-#ident "$Id: quotacheck.c,v 1.54 2008/03/13 14:49:33 jkar8572 Exp $"
+#ident "$Id: quotacheck.c,v 1.57 2008/12/17 12:40:07 jkar8572 Exp $"
 
 #include <dirent.h>
 #include <stdio.h>
@@ -554,7 +554,7 @@ static int scan_dir(char *pathname)
 			if (gcheck)
 				add_to_quota(GRPQUOTA, st.st_ino, st.st_uid, st.st_gid, st.st_mode,
 					     st.st_nlink, qspace, 1);
-			debug(FL_DEBUG, _("\tAdding %s size %Ld ino %d links %d uid %u gid %u\n"), de->d_name,
+			debug(FL_DEBUG, _("\tAdding %s size %lld ino %d links %d uid %u gid %u\n"), de->d_name,
 			      (long long)st.st_size, (int)st.st_ino, (int)st.st_nlink, (int)st.st_uid, (int)st.st_gid);
 			files_done++;
 		}
@@ -721,6 +721,18 @@ static int rename_files(struct mntent *mnt, int type)
 	}
 	if (ioctl(fd, EXT2_IOC_GETFLAGS, &ext2_flags) < 0)
 		debug(FL_DEBUG, _("EXT2_IOC_GETFLAGS failed: %s\n"), strerror(errno));
+	/* IMMUTABLE flag set probably because system crashed and quota was not properly
+	 * turned off */
+	if (ext2_flags & EXT2_IMMUTABLE_FL) {
+		debug(FL_DEBUG | FL_VERBOSE, _("Quota file %s has IMMUTABLE flag set. Clearing.\n"), filename);
+		ext2_flags &= ~EXT2_IMMUTABLE_FL;
+		if (ioctl(fd, EXT2_IOC_SETFLAGS, &ext2_flags) < 0) {
+			errstr(_("Failed to remove IMMUTABLE flag from quota file %s: %s\n"), filename, strerror(errno));
+			free(filename);
+			close(fd);
+			return -1;
+		}
+	}
 	close(fd);
 #endif
 	if (flags & FL_BACKUPS) {
@@ -1036,7 +1048,8 @@ static void check_all(void)
 	while ((mnt = get_next_mount())) {
 		if (flags & FL_ALL && flags & FL_NOROOT && !strcmp(mnt->mnt_dir, "/"))
 			continue;
-		if (!strcmp(mnt->mnt_type, MNTTYPE_XFS) || nfs_fstype(mnt->mnt_type)) {
+		if (!strcmp(mnt->mnt_type, MNTTYPE_XFS) || nfs_fstype(mnt->mnt_type) ||
+		    meta_qf_fstype(mnt->mnt_type)) {
 			debug(FL_DEBUG | FL_VERBOSE, _("Skipping %s [%s]\n"), mnt->mnt_fsname, mnt->mnt_dir);
 			continue;
 		}
@@ -1064,6 +1077,7 @@ static void check_all(void)
 		    !hasmntopt(mnt, MNTOPT_GRPJQUOTA) && !warned &&
 		    (!strcmp(mnt->mnt_type, MNTTYPE_EXT3) ||
 		     !strcmp(mnt->mnt_type, MNTTYPE_EXT4) ||
+		     !strcmp(mnt->mnt_type, MNTTYPE_EXT4DEV) ||
 		     !strcmp(mnt->mnt_type, MNTTYPE_REISER))) {
 			struct utsname stats;
 
